@@ -290,10 +290,12 @@ xfce_mime_chooser_row_can_select (GtkTreeSelection  *selection,
     if (G_UNLIKELY (!path_currently_selected))
     {
         /* check if there's an application for the path */
-        gtk_tree_model_get_iter (model, &iter, path);
-        gtk_tree_model_get_value (model, &iter, CHOOSER_COLUMN_APP_INFO, &value);
-        permitted = (g_value_get_object (&value) != NULL);
-        g_value_unset (&value);
+        if (G_LIKELY (gtk_tree_model_get_iter (model, &iter, path)))
+        {
+            gtk_tree_model_get_value (model, &iter, CHOOSER_COLUMN_APP_INFO, &value);
+            permitted = (g_value_get_object (&value) != NULL);
+            g_value_unset (&value);
+        }
     }
 
     return permitted;
@@ -596,8 +598,8 @@ xfce_mime_chooser_set_mime_type (XfceMimeChooser *chooser,
     gtk_tree_view_expand_all (GTK_TREE_VIEW (chooser->treeview));
 
     /* cleanup */
-    g_list_foreach (recommended, (GFunc) g_object_unref, NULL);
-    g_list_foreach (all, (GFunc) g_object_unref, NULL);
+    g_list_foreach (recommended, (GFunc) (void (*)(void)) g_object_unref, NULL);
+    g_list_foreach (all, (GFunc) (void (*)(void)) g_object_unref, NULL);
     g_list_free (recommended);
     g_list_free (all);
     g_list_free (other);
