@@ -38,6 +38,7 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <dbus/dbus.h>
+#include <dbus/dbus-glib-lowlevel.h>
 
 #ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
@@ -57,6 +58,7 @@
 #include "keyboard-shortcuts.h"
 #include "workspaces.h"
 #include "clipboard-manager.h"
+#include "gtk-decorations.h"
 #include "xsettings.h"
 
 #ifdef HAVE_XRANDR
@@ -118,6 +120,21 @@ dbus_connection_filter_func (DBusConnection *connection,
         }
     }
 
+    if (dbus_message_is_signal (message, DBUS_INTERFACE_DBUS, "NameLost"))
+    {
+        if (dbus_message_get_args (message, NULL,
+                                   DBUS_TYPE_STRING, &name,
+                                   DBUS_TYPE_INVALID))
+        {
+            if (g_strcmp0 (name, XFSETTINGS_DBUS_NAME) == 0)
+            {
+                g_printerr (G_LOG_DOMAIN ": %s\n", "Another instance took over. Leaving...");
+                gtk_main_quit ();
+                return DBUS_HANDLER_RESULT_HANDLED;
+            }
+        }
+    }
+
     return DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
 }
 
@@ -159,6 +176,7 @@ main (gint argc, gchar **argv)
     GObject              *accessibility_helper;
     GObject              *shortcuts_helper;
     GObject              *keyboard_layout_helper;
+    GObject              *gtk_decorations_helper;
     GObject              *xsettings_helper;
     GObject              *clipboard_daemon = NULL;
 #ifdef HAVE_XRANDR
@@ -180,6 +198,7 @@ main (gint argc, gchar **argv)
        g_option_context_add_group (context, gtk_get_option_group (FALSE));
     */
     g_option_context_add_group (context, xfce_sm_client_get_option_group (argc, argv));
+    g_option_context_set_ignore_unknown_options(context, TRUE);
 
     /* parse options */
     if (!g_option_context_parse (context, &argc, &argv, &error))
@@ -200,7 +219,7 @@ main (gint argc, gchar **argv)
     if (G_UNLIKELY (opt_version))
     {
         g_print ("%s %s (Xfce %s)\n\n", G_LOG_DOMAIN, PACKAGE_VERSION, xfce_version_string ());
-        g_print ("%s\n", "Copyright (c) 2008-2011");
+        g_print ("%s\n", "Copyright (c) 2008-2018");
         g_print ("\t%s\n\n", _("The Xfce development team. All rights reserved."));
         g_print (_("Please report bugs to <%s>."), PACKAGE_BUGREPORT);
         g_print ("\n");
@@ -238,6 +257,7 @@ main (gint argc, gchar **argv)
     dbus_connection = dbus_bus_get (DBUS_BUS_SESSION, NULL);
     if (G_LIKELY (dbus_connection != NULL))
     {
+        dbus_connection_setup_with_g_main (dbus_connection, NULL);
         dbus_connection_set_exit_on_disconnect (dbus_connection, FALSE);
 
         dbus_flags = DBUS_NAME_FLAG_ALLOW_REPLACEMENT | DBUS_NAME_FLAG_DO_NOT_QUEUE;
@@ -252,7 +272,12 @@ main (gint argc, gchar **argv)
             return EXIT_SUCCESS;
         }
 
-        dbus_bus_add_match (dbus_connection, "type='signal',member='NameOwnerChanged',arg0='"XFSETTINGS_DBUS_NAME"'", NULL);
+        dbus_bus_add_match (dbus_connection,
+            "type='signal',interface='"DBUS_INTERFACE_DBUS"',member='NameOwnerChanged',arg0='"XFSETTINGS_DBUS_NAME"'",
+            NULL);
+        dbus_bus_add_match (dbus_connection,
+            "type='signal',interface='"DBUS_INTERFACE_DBUS"',member='NameLost',arg0='"XFSETTINGS_DBUS_NAME"'",
+            NULL);
         dbus_connection_add_filter (dbus_connection, dbus_connection_filter_func, NULL, NULL);
     }
     else
@@ -297,6 +322,7 @@ main (gint argc, gchar **argv)
     shortcuts_helper = g_object_new (XFCE_TYPE_KEYBOARD_SHORTCUTS_HELPER, NULL);
     keyboard_layout_helper = g_object_new (XFCE_TYPE_KEYBOARD_LAYOUT_HELPER, NULL);
     workspaces_helper = g_object_new (XFCE_TYPE_WORKSPACES_HELPER, NULL);
+    gtk_decorations_helper = g_object_new (XFCE_TYPE_DECORATIONS_HELPER, NULL);
 
     if (g_getenv ("XFSETTINGSD_NO_CLIPBOARD") == NULL)
     {
@@ -338,6 +364,7 @@ main (gint argc, gchar **argv)
     g_object_unref (G_OBJECT (shortcuts_helper));
     g_object_unref (G_OBJECT (keyboard_layout_helper));
     g_object_unref (G_OBJECT (workspaces_helper));
+    g_object_unref (G_OBJECT (gtk_decorations_helper));
 
     if (G_LIKELY (clipboard_daemon != NULL))
     {
